@@ -16,6 +16,9 @@ import unittest
 
 import mock
 
+from google.cloud.storage.retry import DEFAULT_RETRY
+from google.cloud.storage.retry import DEFAULT_RETRY_IF_ETAG_IN_JSON
+
 
 class TestHMACKeyMetadata(unittest.TestCase):
     @staticmethod
@@ -343,6 +346,7 @@ class TestHMACKeyMetadata(unittest.TestCase):
             "data": {"state": "INACTIVE"},
             "query_params": {},
             "timeout": 42,
+            "retry": DEFAULT_RETRY_IF_ETAG_IN_JSON,
         }
         connection.api_request.assert_called_once_with(**expected_kwargs)
 
@@ -376,6 +380,7 @@ class TestHMACKeyMetadata(unittest.TestCase):
             "data": {"state": "ACTIVE"},
             "query_params": {"userProject": user_project},
             "timeout": self._get_default_timeout(),
+            "retry": DEFAULT_RETRY_IF_ETAG_IN_JSON,
         }
         connection.api_request.assert_called_once_with(**expected_kwargs)
 
@@ -409,6 +414,7 @@ class TestHMACKeyMetadata(unittest.TestCase):
             "path": expected_path,
             "query_params": {},
             "timeout": 42,
+            "retry": DEFAULT_RETRY,
         }
         connection.api_request.assert_called_once_with(**expected_kwargs)
 
@@ -432,6 +438,7 @@ class TestHMACKeyMetadata(unittest.TestCase):
             "path": expected_path,
             "query_params": {"userProject": user_project},
             "timeout": self._get_default_timeout(),
+            "retry": DEFAULT_RETRY,
         }
         connection.api_request.assert_called_once_with(**expected_kwargs)
 
